==> libreoffice-still-sdk-7.1.6-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/typedefs_0.js <==
var searchData=
[
  ['aargs_0',['aArgs',['../structcom_1_1sun_1_1star_1_1frame_1_1DispatchStatement.html#a20d501e18af98299a85ef977713eb4d9',1,'com::sun::star::frame::DispatchStatement']]],
  ['adictionaryevents_1',['aDictionaryEvents',['../structcom_1_1sun_1_1star_1_1linguistic2_1_1DictionaryListEvent.html#a3df5892daee3b49b685ef4a49b36e192',1,'com::sun::star::linguistic2::DictionaryListEvent']]],
  ['adjustmentvalues_2',['AdjustmentValues',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGeometry.html#a0c82cb869bd765fa2b9654365a092988',1,'com::sun::star::drawing::EnhancedCustomShapeGeometry']]],
  ['aerrors_3',['aErrors',['../structcom_1_1sun_1_1star_1_1linguistic2_1_1ProofreadingResult.html#a1ee98fb5d9ae69b4c2864e210df09c01',1,'com::sun::star::linguistic2::ProofreadingResult']]],
  ['ainformation_4',['aInformation',['../structcom_1_1sun_1_1star_1_1frame_1_1ControlEvent.html#a65907552bdce043f1e5fe38558351f37',1,'com::sun::star::frame::ControlEvent']]],
  ['alternativenames_5',['AlternativeNames',['../interfacecom_1_1sun_1_1star_1_1security_1_1XSanExtension.html#afb0abfde404ea99be41e072ff86bbb2c',1,'com::sun::star::security::XSanExtension']]],
  ['anchortypes_6',['AnchorTypes',['../servicecom_1_1sun_1_1star_1_1text_1_1TextContent.html#a34706e309e58d0d4d9b8205a79be8f15',1,'com::sun::star::text::TextContent']]],
  ['aparammodes_7',['aParamModes',['../structcom_1_1sun_1_1star_1_1script_1_1InvocationInfo.html#ad41c90754dfeda5754f3c23266a4679c',1,'com::sun::star::script::InvocationInfo']]],
  ['aparamtypes_8',['aParamTypes',['../structcom_1_1sun_1_1star_1_1script_1_1InvocationInfo.html#a26adf2151fce8beae12d21122908d41b',1,'com::sun::star::script::InvocationInfo']]],
  ['appletcommands_9',['AppletCommands',['../servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html#acd2571f1d4c40bd85fdd7955edc7e9d1',1,'com::sun::star::drawing::AppletShape']]],
  ['aproperties_10',['aProperties',['../structcom_1_1sun_1_1star_1_1linguistic2_1_1ProofreadingResult.html#ab0fdb82cfdb5e221d41b3c954d8f58e3',1,'com::sun::star::linguistic2::ProofreadingResult::aProperties()'],['../structcom_1_1sun_1_1star_1_1linguistic2_1_1SingleProofreadingError.html#ab0fdb82cfdb5e221d41b3c954d8f58e3',1,'com::sun::star::linguistic2::SingleProofreadingError::aProperties()']]],
  ['arguments_11',['Arguments',['../structcom_1_1sun_1_1star_1_1frame_1_1ControlCommand.html#a6ab33f693acab8f91824ca75a91095d6',1,'com::sun::star::frame::ControlCommand::Arguments()'],['../interfacecom_1_1sun_1_1star_1_1report_1_1meta_1_1XFunctionDescription.html#a86cab5c162f9b8be101f252e414d4e4f',1,'com::sun::star::report::meta::XFunctionDescription::Arguments()'],['../servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescription.html#a86cab5c162f9b8be101f252e414d4e4f',1,'com::sun::star::sheet::FunctionDescription::Arguments()'],['../exceptioncom_1_1sun_1_1star_1_1ucb_1_1InteractiveAugmentedIOException.html#a88978336b84fdf6853de0302ab69e37a',1,'com::sun::star::ucb::InteractiveAugmentedIOException::Arguments()'],['../structcom_1_1sun_1_1star_1_1script_1_1AllEventObject.html#a6c262bb48c66916d75e88652d1974af8',1,'com::sun::star::script::AllEventObject::Arguments()']]],
  ['asuggestions_12',['aSuggestions',['../structcom_1_1sun_1_1star_1_1linguistic2_1_1SingleProofreadingError.html#ae3e3edf6079c4392f121606b72f1d9e2',1,'com::sun::star::linguistic2::SingleProofreadingError']]],
  ['atoms_13',['atoms',['../structcom_1_1sun_1_1star_1_1util_1_1AtomClassRequest.html#a6bea44d666163631281aec6ef8f7ea9b',1,'com::sun::star::util::AtomClassRequest']]],
  ['attributeddatapoints_14',['AttributedDataPoints',['../servicecom_1_1sun_1_1star_1_1chart2_1_1DataSeries.html#a299a4c0155d1db14415027d726694485',1,'com::sun::star::chart2::DataSeries']]]
];

==> libreoffice-still-sdk-7.5.7-3-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/typedefs_0.js <==
var searchData=
[
  ['aargs_0',['aArgs',['../structcom_1_1sun_1_1star_1_1frame_1_1DispatchStatement.html#a20d501e18af98299a85ef977713eb4d9',1,'com::sun::star::frame::DispatchStatement']]],
  ['adictionaryevents_1',['aDictionaryEvents',['../structcom_1_1sun_1_1star_1_1linguistic2_1_1DictionaryListEvent.html#a3df5892daee3b49b685ef4a49b36e192',1,'com::sun::star::linguistic2::DictionaryListEvent']]],
  ['adjustmentvalues_2',['AdjustmentValues',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGeometry.html#a0c82cb869bd765fa2b9654365a092988',1,'com::sun::star::drawing::EnhancedCustomShapeGeometry']]],
  ['aerrors_3',['aErrors',['../structcom_1_1sun_1_1star_1_1linguistic2_1_1ProofreadingResult.html#a1ee98fb5d9ae69b4c2864e210df09c01',1,'com::sun::star::linguistic2::ProofreadingResult']]],
  ['ainformation_4',['aInformation',['../structcom_1_1sun_1_1star_1_1frame_1_1ControlEvent.html#a65907552bdce043f1e5fe38558351f37',1,'com::sun::star::frame::ControlEvent']]],
  ['alternativenames_5',['AlternativeNames',['../interfacecom_1_1sun_1_1star_1_1security_1_1XSanExtension.html#afb0abfde404ea99be41e072ff86bbb2c',1,'com::sun::star::security::XSanExtension']]],
  ['anchortypes_6',['AnchorTypes',['../servicecom_1_1sun_1_1star_1_1text_1_1TextContent.html#a34706e309e58d0d4d9b8205a79be8f15',1,'com::sun::star::text::TextContent']]],
  ['aparammodes_7',['aParamModes',['../structcom_1_1sun_1_1star_1_1script_1_1InvocationInfo.html#ad41c90754dfeda5754f3c23266a4679c',1,'com::sun::star::script::InvocationInfo']]],
  ['aparamtypes_8',['aParamTypes',['../structcom_1_1sun_1_1star_1_1script_1_1InvocationInfo.html#a26adf2151fce8beae12d21122908d41b',1,'com::sun::star::script::InvocationInfo']]],
  ['appletcommands_9',['AppletCommands',['../servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html#acd2571f1d4c40bd85fdd7955edc7e9d1',1,'com::sun::star::drawing::AppletShape']]],
  ['aproperties_10',['aproperties',['../structcom_1_1sun_1_1star_1_1linguistic2_1_1ProofreadingResult.html#ab0fdb82cfdb5e221d41b3c954d8f58e3',1,'com::sun::star::linguistic2::ProofreadingResult::aProperties'],['../structcom_1_1sun_1_1star_1_1linguistic2_1_1SingleProofreadingError.html#ab0fdb82cfdb5e221d41b3c954d8f58e3',1,'com::sun::star::linguistic2::SingleProofreadingError::aProperties']]],
  ['arguments_11',['arguments',['../structcom_1_1sun_1_1star_1_1script_1_1AllEventObject.html#a6c262bb48c66916d75e88652d1974af8',1,'com::sun::star::script::AllEventObject::Arguments'],['../structcom_1_1sun_1_1star_1_1frame_1_1ControlCommand.html#a6ab33f693acab8f91824ca75a91095d6',1,'com::sun::star::frame::ControlCommand::Arguments'],['../interfacecom_1_1sun_1_1star_1_1report_1_1meta_1_1XFunctionDescription.html#a86cab5c162f9b8be101f252e414d4e4f',1,'com::sun::star::report::meta::XFunctionDescription::Arguments'],['../servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescription.html#a86cab5c162f9b8be101f252e414d4e4f',1,'com::sun::star::sheet::FunctionDescription::Arguments'],['../exceptioncom_1_1sun_1_1star_1_1ucb_1_1InteractiveAugmentedIOException.html#a88978336b84fdf6853de0302ab69e37a',1,'com::sun::star::ucb::InteractiveAugmentedIOException::Arguments']]],
  ['asuggestions_12',['aSuggestions',['../structcom_1_1sun_1_1star_1_1linguistic2_1_1SingleProofreadingError.html#ae3e3edf6079c4392f121606b72f1d9e2',1,'com::sun::star::linguistic2::SingleProofreadingError']]],
  ['atoms_13',['atoms',['../structcom_1_1sun_1_1star_1_1util_1_1AtomClassRequest.html#a6bea44d666163631281aec6ef8f7ea9b',1,'com::sun::star::util::AtomClassRequest']]],
  ['attributeddatapoints_14',['AttributedDataPoints',['../servicecom_1_1sun_1_1star_1_1chart2_1_1DataSeries.html#a299a4c0155d1db14415027d726694485',1,'com::sun::star::chart2::DataSeries']]]
];
